import List from '@mui/material/List';
import ListItemButton from '@mui/material/ListItemButton';
import Avatar from '@mui/material/Avatar';
import ListItemText from '@mui/material/ListItemText';
import ListItemIcon from '@mui/material/ListItemIcon';
import { makeStyles, Typography } from '@material-ui/core'
import { useState,useEffect } from 'react';
import shortid from 'shortid';
import { useSelector, useDispatch } from 'react-redux';
import AlertInfo from '../../../reusableComponents/AlertInfo'

import doubleCheck from '../../../../img/clipart289625.png'
import { firstLetter, slicedWord, timeStamp } from '../../../../helpers'
import { getState } from '../../../../redux/chats/selector'
import { asyncGetChats } from '../../../../redux/chats/operations'
import { asyncStartChatById } from '../../../../redux/chat/operations'

const useStyles = makeStyles({
  list: {
    width: '100%',
    maxHeight: '890px',
    overflowY: 'scroll',
  '&::-webkit-scrollbar': {
    width: '0.4em'
  },
  '&::-webkit-scrollbar-track': {
    boxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    webkitBoxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    backgroundColor: '#eceeec',
  },
  '&::-webkit-scrollbar-thumb': {
    backgroundColor: '#ccc8c8',
    },
  "&::-webkit-scrollbar-thumb:focus": {
    backgroundColor: "#959595",
          },
  "&::-webkit-scrollbar-thumb:active": {
    backgroundColor: "#959595",
    },
  },
  listItem: {},
  listItem_iconAvatar: {
    marginRight:10
  },
  listItem_iconRight: {
    marginRight: 10,
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    alignContent: 'center',
    flexDirection: 'column'
  },
  listItem_iconTimeChecked: {
    display: 'flex',
    flexWrap: 'nowrap',
    alignItems: 'center',
    justifyContent: 'center',
    alignContent: 'center',
    marginBottom:2
  },
  listItem_iconRightBtn: {
    background: '#0ac40a',
    borderRadius: '50%',
    color: '#ffffff',
    border: 'none',
    height: 24,
    width: 24,
    textAlign: 'center',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    alignContent: 'center',
    fontSize: 12,
    marginLeft: 'auto',
    '&:hover': {
      outline: 'solid 3px #3ee415',
    }
  },
  listItem_icon_time: {
    fontSize: 12,
    marginLeft: 5,
    color: '#1b1b1b'
  }
})

const ChatsList = () => {
  const classes = useStyles()
  const dispatch = useDispatch()
  const [selectedIndex, setSelectedIndex] = useState<number>(1);
  const { total, chats , lastMessages } = useSelector(getState)
 

  const handleListItemClick = async (i: number, companionId: string) => {
      await dispatch(asyncStartChatById(companionId))
      setSelectedIndex(i);
  }

  const handleNewMsgS = (e: React.MouseEvent<HTMLButtonElement, MouseEvent>, i: number) => {
    e.stopPropagation()
    console.log(i,'index','clicked read new messages')
  }

  useEffect(() => {
    const handleReset = () => dispatch(asyncGetChats())
    const idInterval = setInterval(handleReset, 10000);
    return () => clearInterval(idInterval);
  }, [dispatch]);
  
  useEffect(() => {
    dispatch(asyncGetChats())
  }, [dispatch])
  
  return total !== '0' ? (
    <List className={classes.list} component="nav"
          aria-label="main mailbox folders">
      {chats.map(({name, lastName, avatarUrl, updatedAt, color,companionId }, i: number) => 
          <ListItemButton
          className={classes.listItem}
          key={shortid.generate()}
          selected={selectedIndex === i}
          onClick={(e) => handleListItemClick(i,companionId)}
          >
          <ListItemIcon className={classes.listItem_iconAvatar}>
            <Avatar alt={name} src={avatarUrl?`http://localhost:3000/${avatarUrl}`:undefined}
                 sx={{ background: color, width: 54, height: 54 }}>
                 {!avatarUrl&&`${firstLetter(name)}${firstLetter(lastName)}`}
              </Avatar>
          </ListItemIcon> 
          <ListItemText primary={`${firstLetter(name)}${slicedWord(name, 15, 1)} 
             ${firstLetter(lastName)}${slicedWord(lastName, 15, 1)}`}
              secondary={slicedWord(lastMessages[i]?lastMessages[i].message:'No messages yet', 35)} />
          <ListItemIcon className={classes.listItem_iconRight}>
               <div className={classes.listItem_iconTimeChecked}>
                 <img alt='double check' width="16" height='16' src={doubleCheck} />
                 <Typography  className={classes.listItem_icon_time} variant="h6"   color="initial">{timeStamp(updatedAt)}</Typography>
               </div>
               <button onClick={(e) => handleNewMsgS(e,i)} className={classes.listItem_iconRightBtn}>17</button>
          </ListItemIcon>            
        </ListItemButton>)}
      </List>
  ):<AlertInfo name='You do not have any chats yet!' />;
}

export default ChatsList